Post

Just tried new Kotlin/Native smallBinary option in Kotlin 2.2.20-Beta1.in project here (github.com/joreilly/Con...) and seeing over 20% reduction in size when building release version 🚀 btw remember to set following! kotlin.native.binary.smallBinary=true

1 repost20 likes

Build time improved quite a bit as well.....ran a few before/after builds and went on average (again for Confetti project) from 476s to 344s (this was for case when running archive build in Xcode)